.. :changelog:

History
-------

0.1 (2017-12-24)
----------------

* First release


1.1 (2018-03-18)
----------------

* Exposed the location of the actual account if shared (Contribution by: Amy Nagle <kabi-git@openmuffin.com>)


1.2 (2018-04-02)
----------------

* Re-exposed the accuracy of the GPS.


1.3 (2018-05-5)
----------------

* Implemented 2FA method and added cli tool "get-maps-cookies" to help with retrieval of cookies. (With contribution by Chris Helming)


3.0 (2018-09-30)
----------------

* Dropped python2 support.
* Added battery level and charging status (Contribution by Amy Nagle)
